 typedef xcb_char2b_t XCBChar2b;
 typedef xcb_point_t XCBPoint;
 typedef xcb_rectangle_t XCBRectangle;
 typedef xcb_arc_t XCBArc;
 typedef xcb_format_t XCBFormat;
 typedef xcb_visualtype_t XCBVisualtype;
 typedef xcb_depth_t XCBDepth;
 typedef xcb_screen_t XCBScreen;
 typedef xcb_setup_request_t XCBSetup_request;
 typedef xcb_setup_failed_t XCBSetup_failed;
 typedef xcb_setup_authenticate_t XCBSetup_authenticate;
 typedef xcb_setup_t XCBSetup;
 typedef xcb_timecoord_t XCBTimecoord;
 typedef xcb_fontprop_t XCBFontprop;
 typedef xcb_charinfo_t XCBCharinfo;
 typedef xcb_str_t XCBStr;
 typedef xcb_segment_t XCBSegment;
 typedef xcb_coloritem_t XCBColoritem;
 typedef xcb_rgb_t XCBRgb;
 typedef xcb_host_t XCBHost;
 typedef xcb_xinerama_screen_info_t XCBXinerama_screen_info;
